@@ -440,11 +440,12 @@ def apply_discretization_two_states_lo(y_pred, splitting_threshold):
 def discretize_two_states_lo(y_pred, splitting_quantile_threshold=0.5):
     y_pred_discrete = np.zeros(y_pred.shape)
     threshold = np.nan
+    trouble = False
     try:
         threshold = np.quantile(y_pred, splitting_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
+        trouble=True
+
     if np.isnan(threshold) :
         threshold = 0.5
     y_pred_discrete[y_pred > threshold] = 1.
@@ -468,19 +469,19 @@ def discretize_three_states(y_pred, upper_quantile_threshold=0.8, lower_quantile
 
     y_pred_discrete = np.zeros(y_pred.shape)
 
+    trouble = False
     lower_threshold = np.nan
     try:
         lower_threshold = np.quantile(y_pred, lower_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
+        trouble = True
+
 
     upper_threshold = np.nan
     try:
         upper_threshold = np.quantile(y_pred, upper_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
+        trouble = True
 
     if np.isnan(upper_threshold):
         upper_threshold = 0.8
@@ -526,19 +527,17 @@ def apply_discretization_three_states_lo(y_pred, upper_threshold, lower_threshol
 def discretize_three_states_lo(y_pred, upper_quantile_threshold=0.8, lower_quantile_threshold = 0.2):
     y_pred_discrete = np.ones(y_pred.shape)/2
 
+    trouble = False
     lower_threshold = np.nan
     try:
         lower_threshold = np.quantile(y_pred, lower_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
-
+        trouble =True
     upper_threshold = np.nan
     try:
         upper_threshold = np.quantile(y_pred, upper_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
+        trouble =True
 
     if np.isnan(upper_threshold):
         upper_threshold = 0.8
